aboutsummaryrefslogtreecommitdiff
path: root/azalea-protocol/src/packets/handshake
diff options
context:
space:
mode:
Diffstat (limited to 'azalea-protocol/src/packets/handshake')
-rwxr-xr-xazalea-protocol/src/packets/handshake/client_intention_packet.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/azalea-protocol/src/packets/handshake/client_intention_packet.rs b/azalea-protocol/src/packets/handshake/client_intention_packet.rs
index 5f1987e2..804778a0 100755
--- a/azalea-protocol/src/packets/handshake/client_intention_packet.rs
+++ b/azalea-protocol/src/packets/handshake/client_intention_packet.rs
@@ -1,9 +1,9 @@
use crate::packets::ConnectionProtocol;
use azalea_buf::McBuf;
-use packet_macros::HandshakePacket;
+use packet_macros::ClientboundHandshakePacket;
use std::hash::Hash;
#[derive(Hash, Clone, Debug, McBuf, HandshakePacket)]
pub struct ClientIntentionPacket {
#[var]
pub protocol_version: u32,
@@ -1,9 +1,9 @@
use std::hash::Hash;
-#[derive(Hash, Clone, Debug, McBuf, HandshakePacket)]
+#[derive(Hash, Clone, Debug, McBuf, ClientboundHandshakePacket)]
pub struct ClientIntentionPacket {
#[var]